@@ -27,7 +27,7 @@ class FakeRepository(Repository):
         self.entities: FakeRepositoryDB[Entity] = {}
         self.new_entities: FakeRepositoryDB[Entity] = {}
 
-    def add(self, entity: Entity) -> Entity:
+    def _add(self, entity: Entity) -> Entity:
         """Append an entity to the repository.
 
         If the id is not set, autoincrement the last.
@@ -38,8 +38,6 @@ class FakeRepository(Repository):
         Returns:
             entity
         """
-        if isinstance(entity.id_, int) and entity.id_ < 0:
-            entity.id_ = self._next_id(entity)
         if self.new_entities == {}:
             self.new_entities = copy.deepcopy(self.entities.copy())
         try:
